# Bayesian analysis of orangutan data

# Do the 'columns' of a Bayes Table
N <- 1:600
N
# PRIOR
priorMean <- 240
priorSD <- 100
prior <- dnorm(N, priorMean, priorSD)
plot(N, prior)

# Put N and prior into a data frame so that we can use View
ou <- data.frame(N, prior)
View(ou)   # close the View window when done.

# LIKELIHOOD
count <- 19
ou$D <- N / 160  # density, orangutan/sq km
ou$lambda <- ou$D * 10  # Number we'd expect in 10 sq km
View(ou)

ou$llh <- dpois(count, ou$lambda)
View(ou)
llh2plot <- ou$llh / sum(ou$llh)
lines(N, llh2plot, lty=2)  # Ooops! we'll replot later

# PRODUCT
ou$product <- ou$llh * ou$prior

# POSTERIOR
ou$post <- ou$product / sum(ou$product)
View(ou)
plot(ou$N, ou$post, col='darkgreen')
points(ou$N, llh2plot, col='purple')
points(ou$N, ou$prior, col='blue')

# Posterior mean
sum(ou$N * ou$post)

# Posterior mode
which.max(ou$post)

# Posterior median and credible interval
# Calculate cumulative probability
ou$cum.post <- cumsum(ou$post)
View(ou)
# Median: Look down the cum.post column and find the value closest to 0.5 (5.000e-1)
# 288
# Lower CrI: Look for first value after  0.025 (2.500e-2)
# Upper CrI: Look for first value before 0.975 (9.750e-1)
# 192, 404

# Probability that there are > 400 orangutan in the Park:
sum(ou$post[ou$N > 400])

# Get a 95% HDI
library(wiqid)
plotComb(ou$N, ou$post)
# What values did we get before
abline(v=192, col='blue')
abline(v=404, col='blue')
